Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mapsme/omim.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorVladimir Byko-Ianko <v.bykoianko@corp.mail.ru>2017-10-25 15:09:43 +0300
committermpimenov <mpimenov@users.noreply.github.com>2017-10-25 17:10:31 +0300
commit2299f4c5a466cfbdc69106193309541843d62876 (patch)
tree2dcd003dbbd65eb863de3bcba30d70cf2c89fba4
parentf8545f98718cdb4fce3be80dd1bddcd8a83a26e3 (diff)
Renaming mapping.
-rw-r--r--generator/transit_generator.cpp10
-rw-r--r--generator/transit_generator.hpp4
2 files changed, 7 insertions, 7 deletions
diff --git a/generator/transit_generator.cpp b/generator/transit_generator.cpp
index 4d6753029a..49758bf63f 100644
--- a/generator/transit_generator.cpp
+++ b/generator/transit_generator.cpp
@@ -166,13 +166,13 @@ void CalculateEdgeWeight(vector<Stop> const & stops, vector<transit::Edge> & edg
}
}
-void FillOsmIdToFeatureIdMap(string const & osmIdsToFeatureIdPath, OsmIdToFeatureIdsMap & map)
+void FillOsmIdToFeatureIdsMap(string const & osmIdToFeatureIdsPath, OsmIdToFeatureIdsMap & map)
{
- CHECK(ForEachOsmId2FeatureId(osmIdsToFeatureIdPath,
+ CHECK(ForEachOsmId2FeatureId(osmIdToFeatureIdsPath,
[&map](osm::Id const & osmId, uint32_t featureId) {
map[osmId].push_back(featureId);
}),
- (osmIdsToFeatureIdPath));
+ (osmIdToFeatureIdsPath));
}
} // namespace
@@ -221,7 +221,7 @@ void DeserializerFromJson::operator()(StopIdRanges & rs, char const * name)
}
void BuildTransit(string const & mwmDir, string const & countryId,
- string const & osmIdsToFeatureIdPath, string const & transitDir)
+ string const & osmIdToFeatureIdsPath, string const & transitDir)
{
LOG(LERROR, ("This method is under construction and should not be used for building production mwm "
"sections."));
@@ -258,7 +258,7 @@ void BuildTransit(string const & mwmDir, string const & countryId,
CHECK(root.get() != nullptr, ("Cannot parse the json file:", graphFullPath));
OsmIdToFeatureIdsMap mapping;
- FillOsmIdToFeatureIdMap(osmIdsToFeatureIdPath, mapping);
+ FillOsmIdToFeatureIdsMap(osmIdToFeatureIdsPath, mapping);
// Note. |gates| has to be deserialized from json before starting writing transit section to mwm since
// the mwm is used to filled |gates|.
diff --git a/generator/transit_generator.hpp b/generator/transit_generator.hpp
index 9bd5b1297d..ca57bf3ec7 100644
--- a/generator/transit_generator.hpp
+++ b/generator/transit_generator.hpp
@@ -110,12 +110,12 @@ private:
/// \brief Builds the transit section in the mwm.
/// \param mwmDir relative or full path to a directory where mwm is located.
/// \param countryId is an mwm name without extension of the processed mwm.
/// \param osmIdsToFeatureIdPath is a path to a file with osm ids to feature id mapping.
/// \param transitDir a path to directory with json files with transit graphs.
/// \note An mwm pointed by |mwmPath| should contain:
/// * feature geometry
/// * index graph (ROUTING_FILE_TAG)
void BuildTransit(string const & mwmDir, string const & countryId,
- string const & osmIdsToFeatureIdPath, string const & transitDir);
+ string const & osmIdToFeatureIdsPath, string const & transitDir);
} // namespace transit
} // namespace routing
@@ -110,12 +110,12 @@ private:
/// \param mwmDir relative or full path to a directory where mwm is located.
/// \param countryId is an mwm name without extension of the processed mwm.
-/// \param osmIdsToFeatureIdPath is a path to a file with osm ids to feature id mapping.
+/// \param osmIdToFeatureIdsPath is a path to a file with osm id to feature ids mapping.
/// \param transitDir a path to directory with json files with transit graphs.
/// \note An mwm pointed by |mwmPath| should contain: